export type DirsOptions = {
    /**
     * prefix to prepend to each scope entry (e.g:
     * `{ prefix: 'prefix' }` becomes `type(prefix/scope)`)
     */
    prefix?: string | undefined;
    /**
     * expression for excluding
     * directories, defaults to `^node_modules`
     */
    exclude?: string | RegExp | null | undefined;
};
export namespace ls {
    export { configs };
    export { dirs };
}
export namespace scopes {
    export { build };
}
/**
 * Enumerate config files
 *
 * @example
 *
 * - `dir/foo.js`
 * - `dir/bar.config.js`
 * - `dir/baz.json`
 * - `dir/qux.ts`
 *
 * `ls.config('./dir') → ['dir/foo', 'dir/bar', 'dir/baz', 'dir/qux']`
 *
 * @param {string} path - directory to enumerate
 */
declare function configs(path: string): string[];
/**
 * @typedef DirsOptions
 * @property {string} [prefix] prefix to prepend to each scope entry (e.g:
 * `{ prefix: 'prefix' }` becomes `type(prefix/scope)`)
 * @property {RegExp | string | null} [exclude] expression for excluding
 * directories, defaults to `^node_modules`
 */
/**
 * Enumerate one level of directories
 *
 * @param {string} path - directory to enumerate
 * @param {DirsOptions} [options] - options
 */
declare function dirs(path: string, options?: DirsOptions | undefined): string[];
/**
 * Build scopes
 * - commit
 * - deps
 * - deps-dev
 * - format
 * - lint
 */
declare function build(): string[];
export {};
//# sourceMappingURL=commit.d.ts.map